Grid

Struct Grid 

pub struct Grid { /* private fields */ }
Simple grid container placing widgets in fixed-size cells.

Implementations

Source

impl Grid

pub fn new(cols: i32, cell_w: i32, cell_h: i32) -> Self

Create a new grid with the given cell size and column count.

pub fn spacing(self, spacing: i32) -> Self

Set the spacing between grid cells.

pub fn gap(self, gap: i32) -> Self

Set the gap between grid cells.

pub fn child<W, F>(self, builder: F) -> Self
where W: Widget + 'static, F: FnOnce(Rect) -> W,

Add a child placed in the next grid cell.