pub struct Color(pub u8, pub u8, pub u8, pub u8);Expand description
RGBA color used by the renderer.
Tuple Fields
0: u8Red component in the range 0..=255.
1: u8Green component in the range 0..=255.
2: u8Blue component in the range 0..=255.
3: u8Alpha component in the range 0..=255.
A value of 255 is fully opaque and 0 is fully transparent.
Implementations
Sourceimpl Color
impl Color
Sourcepub fn to_argb8888(self) -> u32
pub fn to_argb8888(self) -> u32
Convert this color to a packed ARGB8888 integer.
Used by display backends in the
rlvgl-platform crate.
Sourcepub fn with_alpha(self, opacity: u8) -> Color
pub fn with_alpha(self, opacity: u8) -> Color
Return a copy with the alpha channel multiplied by opacity.
Both the existing alpha and opacity are in 0..=255.